@@ -10,6 +10,7 @@ import json
 import logging
 import getpass
 import difflib
+import errno
 
 from . import get_project, init_project
 from . import __version__
@@ -100,10 +101,7 @@ def _update_password(config, hostname, scheme=None, new_pw=None):
 
 
 def _read_index(project, fn_index=None):
-    if fn_index is None:
-        _print_err("Indexing project...")
-        return project.index()
-    else:
+    if fn_index is not None:
         _print_err("Reading index from file '{}'...".format(fn_index))
         fd = open(fn_index)
         return (json.loads(l) for l in fd)
@@ -164,7 +162,10 @@ def main_statepoint(args):
         if not m.match(job_id):
             raise ValueError(
                 "'{}' is not a valid job id!".format(job_id))
-        print(json.dumps(_open_job_id(project, job_id).statepoint(), indent=args.indent))
+        print(json.dumps(
+                _open_job_by_id(project, job_id).statepoint(),
+                indent=args.indent,
+                sort_keys=args.sort))
 
 
 def main_move(args):
@@ -214,8 +215,14 @@ def main_find(args):
         df = json.loads(args.doc_filter)
 
     index = _read_index(project, args.index)
-    for job_id in project.find_job_ids(index=index, filter=f, doc_filter=df):
-        print(job_id)
+    try:
+        for job_id in project.find_job_ids(index=index, filter=f, doc_filter=df):
+            print(job_id)
+    except IOError as error:
+        if error.errno == errno.EPIPE:
+            sys.stderr.close()
+        else:
+            raise
 
 
 def main_view(args):
@@ -572,6 +579,10 @@ def main():
         nargs='?',
         const='2',
         help="Specify the indentation of the JSON formatted state point.")
+    parser_statepoint.add_argument(
+        '-s', '--sort',
+        action='store_true',
+        help="Sort the state point keys for output.")
     parser_statepoint.set_defaults(func=main_statepoint)
 
     parser_move = subparsers.add_parser('move')
