@@ -4,11 +4,11 @@
 import os
 import errno
 import logging
-import json
 import shutil
 import copy
 
 from ..common import six
+from ..core.json import json
 from ..core.jsondict import JSonDict
 from ..core.attr_dict import AttrDict
 from ..core.attr_dict import convert_to_dict
@@ -87,7 +87,7 @@ class Job(object):
 
         :param new_statepoint: The job's new state point.
         :type new_statepoint: mapping
-        :raises RuntimeError:
+        :raises DestinationExistsError:
             If a job associated with the new state point is already initialized.
         :raises OSError:
             If the move failed due to an unknown system related error.
@@ -104,7 +104,7 @@ class Job(object):
             except OSError as error:
                 os.rename(fn_manifest_backup, fn_manifest)  # rollback
                 if error.errno == errno.ENOTEMPTY:
-                    raise RuntimeError("Destination exists: {}".format(dst))
+                    raise DestinationExistsError(dst)
                 else:
                     raise
             else:
@@ -138,7 +138,7 @@ class Job(object):
         :raises KeyError:
             If the update contains keys, which are already part of the job's
             state point and overwrite is False.
-        :raises RuntimeError:
+        :raises DestinationExistsError:
             If a job associated with the new state point is already initialized.
         :raises OSError:
             If the move failed due to an unknown system related error.
@@ -224,7 +224,7 @@ class Job(object):
         try:
             try:
                 with open(fn_manifest) as file:
-                    assert calc_id(json.load(file)) == self._id
+                    assert calc_id(json.loads(file.read())) == self._id
             except IOError as error:
                 if not error.errno == errno.ENOENT:
                     raise error
