@@ -5,13 +5,13 @@ from __future__ import print_function
 import os
 import re
 import logging
-import json
 import errno
 import warnings
 import collections
 import shutil
 from itertools import chain
 
+from ..core.json import json
 from ..core.search_engine import DocumentSearchEngine
 from ..common import six
 from ..common.config import load_config
@@ -451,7 +451,7 @@ class Project(object):
         fn_manifest = os.path.join(self.workspace(), jobid, self.Job.FN_MANIFEST)
         try:
             with open(fn_manifest, 'r') as manifest:
-                return json.load(manifest)
+                return json.loads(manifest.read())
         except (IOError, ValueError) as error:
             if os.path.isfile(fn_manifest):
                 msg = "Error while trying to access manifest file: "\
@@ -590,7 +590,7 @@ class Project(object):
         :type job: :class:`~.contrib.job.Job`
         :param new_statepoint: The job's new state point.
         :type new_statepoint: mapping
-        :raises RuntimeError:
+        :raises DestinationExistsError:
             If a job associated with the new state point is already initialized.
         :raises OSError:
             If the move failed due to an unknown system related error.
@@ -616,7 +616,7 @@ class Project(object):
         :raises KeyError:
             If the update contains keys, which are already part of the job's
             state point and overwrite is False.
-        :raises RuntimeError:
+        :raises DestinationExistsError:
             If a job associated with the new state point is already initialized.
         :raises OSError:
             If the move failed due to an unknown system related error.
@@ -653,7 +653,7 @@ class Project(object):
             fn_manifest = os.path.join(job_dir, self.Job.FN_MANIFEST)
             try:
                 with open(fn_manifest) as manifest:
-                    statepoint = json.load(manifest)
+                    statepoint = json.loads(manifest.read())
             except Exception as error:
                 logger.warning(
                     "Encountered error while reading from '{}'. "
