@@ -7,6 +7,7 @@ import errno
 import logging
 import uuid
 
+from .json import json
 from ..common import six
 
 if six.PY2:
@@ -14,10 +15,6 @@ if six.PY2:
 else:
     from collections import UserDict
 
-try:
-    import bson.json_util as json
-except ImportError:
-    import json
 
 logger = logging.getLogger(__name__)
 
